<?php
/**
 * VibeForms Actions hooks
 *
 * @author 		VibeThemes
 * @category 	Init
 * @package 	vibeforms/Includes
 * @version     1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


class VibeForms_Actions{

	public static $instance;
    
    public static function init(){

        if ( is_null( self::$instance ) )
            self::$instance = new VibeForms_Actions();
        return self::$instance;
    }

	private function __construct(){
		add_action( 'bp_setup_nav', array($this,'add_tab'), 100 );
		add_action( 'bp_init', array($this,'setup_group_nav') );
		add_action('wp_enqueue_scripts',array($this,'scripts'));
		add_action('init', array($this,'register_forms'));
	}

	function add_tab(){
		global $bp;
		//Add VibeDrive tab in profile menu
	    bp_core_new_nav_item( array( 
	        'name' => __('Forms','vibeforms'),
	        'slug' => VIBEFORMS_SLUG, 
	        'item_css_id' => 'forms',
	        'screen_function' => array($this,'show_forms'),
	        'default_subnav_slug' => 'home', 
	        'position' => 20
	    ) );

	    

		//Add mydrive submenu in gift tab
	    bp_core_new_subnav_item( array(
			'name' 		  => __( 'Shared Forms', 'vibeforms' ),
			'slug' 		  => 'shared_forms',
			'parent_slug' => VIBEFORMS_SLUG,
        	'parent_url' => $bp->displayed_user->domain.VIBEFORMS_SLUG.'/',
			'screen_function' => array($this,'show_forms'),
			'user_has_access' => (bp_is_my_profile() || current_user_can('manage_options'))
		) );

		//Add mydrive submenu in gift tab
	    bp_core_new_subnav_item( array(
			'name' 		  => __( 'My Forms', 'vibeforms' ),
			'slug' 		  => 'my_forms',
			'parent_slug' => VIBEFORMS_SLUG,
        	'parent_url' => $bp->displayed_user->domain.VIBEFORMS_SLUG.'/',
			'screen_function' => array($this,'show_forms'),
			'user_has_access' => (bp_is_my_profile() || current_user_can('manage_options'))
		) );
	}

	function show_forms(){

	}

	function setup_group_nav(){

	}

	function scripts(){
		wp_enqueue_script('vibeforms-global',plugins_url('../assets/js/vibeforms-global.js',__FILE__),array('wp-element','wp-data'),VIBEFORMS_VERSION,true);
		wp_enqueue_script('vibeforms-global-popup',plugins_url('../assets/js/global_popup_button.js',__FILE__),array('wp-element','wp-data'),VIBEFORMS_VERSION,true);
		
		wp_enqueue_style('vibeforms_profile_css',plugins_url('../assets/css/vibeforms.css',__FILE__),array(),VIBEFORMS_VERSION);
		
		

		
		$vibe_forms_settings= vibe_forms_get_script_data();
		wp_localize_script('vibeforms-global','vibeforms',$vibe_forms_settings);

		if(function_exists('bp_is_user') && bp_is_user() || apply_filters('vibebp_enqueue_profile_script',false)){
			/***********************Live**********************/
			wp_enqueue_script('vibeforms',plugins_url('../assets/js/vibeforms.js',__FILE__),array('wp-element','wp-data'),VIBEFORMS_VERSION,true);
			wp_enqueue_script('tabulator',plugins_url('../assets/js/tabulator.min.js',__FILE__),array(),VIBEFORMS_VERSION,true);
			wp_enqueue_style('tabulator_css',plugins_url('../assets/css/tabulator.min.css',__FILE__),array(),VIBEFORMS_VERSION);
		}
	}

	//Called on Activation hook
	function register_forms(){
		register_post_type( 'vibeform',
			array(
				'labels' => array(
					'name' => __('Forms','vibeforms'),
					'menu_name' => __('Forms','vibeforms'),
					'singular_name' => __('Form','vibeforms'),
					'add_new_item' => __('Add New Form','vibeforms'),
					'all_items' => __('Forms','vibeforms')
				),
				'public' => false,
				'publicly_queryable' => true,
				'show_ui' => true,
				'capability_type' => 'post',
	            'has_archive' => false,
				'show_in_menu' => defined('VIBEBP_VERSION')?'vibebp':'forms',
				'show_in_admin_bar' => false,
				'show_in_nav_menus' => true,
				'supports' => array( 'title','thumbnail','author','comments','excerpt','revisions','custom-fields', 'page-attributes'),
				'hierarchical' => true,
				'rewrite' => array( 'slug' => VIBEFORMS_SLUG, 'hierarchical' => true, 'with_front' => false )
			)
		);

		register_taxonomy( 'vibeform-type', array( 'vibeform'),
			array(
				'labels' => array(
				'name' => __('Forms Type','vibeforms'),
				'menu_name' => __('Form Types','vibeforms'),
				'singular_name' => __('Form Type','vibeforms'),
				'add_new_item' => __('Add New Type','vibeforms'),
				'all_items' => __('All Form Types','vibeforms')
			),
			'public' => false,
			'hierarchical' => true,
			'show_ui' => true,
			'show_in_menu' => defined('VIBEBP_VERSION')?'vibebp':'forms',
			'show_admin_column' => true,
			'show_in_admin_bar' => false,
			'show_in_nav_menus' => true,
			'rewrite' => array( 'slug' => VIBEFORMS_TYPE_SLUG, 'hierarchical' => true, 'with_front' => false ),
			)
		);
	}
}

VibeForms_Actions::init();